==> openGion_dev_5.1.1.0.zip: opengion/uap/webapps/gf/db/mysql/sql/01_TABLE/GF41S.sql <==
/**************************************************************************/
/* GF41 ( トレーニングラベル定義 )                                        */
/*                                                                        */
/* Created : 2009/11/17 09:27:39                                          */
/**************************************************************************/
CREATE TABLE GF41 (
   SYSTEM_ID  VARCHAR(10)                 NOT NULL                                 /* 10  システムID   */
 , LANG       VARCHAR(2)                  NOT NULL                                 /* 20  言語         */
 , CLM        VARCHAR(30)                 NOT NULL                                 /* 30  項目         */
 , NAME_JA    VARCHAR(200)                                                         /* 40  名称         */
 , LABEL_NAME VARCHAR(60)                                                          /* 50  表示名称     */
 , KBSAKU     VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 60  作成区分     */
 , URL        VARCHAR(200)                                                         /* 70  URL          */
 , COMMENTS   VARCHAR(500)                                                         /* 80  コメント     */
 , CDTAN      VARCHAR(10)                                                          /* 90  担当者       */
 , UNIQ       BIGINT                      NOT NULL PRIMARY KEY AUTO_INCREMENT      /* 800 ユニークキー */
 , FGJ        VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 810 状態フラグ   */
 , DYSET      VARCHAR(14)                                                          /* 820 登録日時     */
 , PGSET      VARCHAR(10)                                                          /* 830 作成PG       */
 , PGPSET     VARCHAR(10)                                                          /* 840 作成親PG     */
 , USRSET     VARCHAR(10)                                                          /* 850 作成社員     */
 , DYUPD      VARCHAR(14)                                                          /* 860 更新日時     */
 , PGUPD      VARCHAR(10)                                                          /* 870 更新PG       */
 , PGPUPD     VARCHAR(10)                                                          /* 880 更新親PG     */
 , USRUPD     VARCHAR(10)                                                          /* 890 更新者       */
);

==> openGion_dev_5.1.1.2.zip: opengion/uap/webapps/gf/db/mysql/sql/01_TABLE/GF41S.sql <==
/**************************************************************************/
/* GF41 ( トレーニングラベル定義 )                                        */
/*                                                                        */
/* Created : 2009/12/10 12:30:00                                          */
/**************************************************************************/
CREATE TABLE GF41 (
   SYSTEM_ID  VARCHAR(10)                 NOT NULL                                 /* 10  システムID   */
 , LANG       VARCHAR(2)                  NOT NULL                                 /* 20  言語         */
 , CLM        VARCHAR(30)                 NOT NULL                                 /* 30  項目         */
 , NAME_JA    VARCHAR(200)                                                         /* 40  名称         */
 , LABEL_NAME VARCHAR(60)                                                          /* 50  表示名称     */
 , KBSAKU     VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 60  作成区分     */
 , URL        VARCHAR(200)                                                         /* 70  URL          */
 , COMMENTS   TEXT                                                                 /* 80  コメント     */
 , CDTAN      VARCHAR(10)                                                          /* 90  担当者       */
 , UNIQ       BIGINT                      NOT NULL PRIMARY KEY AUTO_INCREMENT      /* 800 ユニークキー */
 , FGJ        VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 810 状態フラグ   */
 , DYSET      VARCHAR(14)                                                          /* 820 登録日時     */
 , PGSET      VARCHAR(10)                                                          /* 830 作成PG       */
 , PGPSET     VARCHAR(10)                                                          /* 840 作成親PG     */
 , USRSET     VARCHAR(10)                                                          /* 850 作成社員     */
 , DYUPD      VARCHAR(14)                                                          /* 860 更新日時     */
 , PGUPD      VARCHAR(10)                                                          /* 870 更新PG       */
 , PGPUPD     VARCHAR(10)                                                          /* 880 更新親PG     */
 , USRUPD     VARCHAR(10)                                                          /* 890 更新者       */
);
